@@ -1,4 +1,4 @@
-from algora.common.base import BaseEnum
+from algora.common.base_enum import BaseEnum
 
 
 class BacktestEventType(BaseEnum):
